@@ -1,18 +1,18 @@
 package TeX::AutoTeX::PostScript;
 
 #
-# $Id: PostScript.pm,v 1.11.2.5 2011/01/27 18:42:28 thorstens Exp $
-# $Revision: 1.11.2.5 $
+# $Id: PostScript.pm,v 1.11.2.4 2011/01/03 04:06:00 thorstens Exp $
+# $Revision: 1.11.2.4 $
 # $Source: /cvsroot/arxivlib/arXivLib/lib/TeX/AutoTeX/PostScript.pm,v $
 #
-# $Date: 2011/01/27 18:42:28 $
+# $Date: 2011/01/03 04:06:00 $
 # $Author: thorstens $
 #
 
 use strict;
 ### use warnings;
 
-our ($VERSION) = '$Revision: 1.11.2.5 $' =~ m{ \$Revision: \s+ (\S+) }x;
+our ($VERSION) = '$Revision: 1.11.2.4 $' =~ m{ \$Revision: \s+ (\S+) }x;
 
 sub fix_ps_title {
   my ($sfile, $dir, $title, $log) = @_;
@@ -154,7 +154,7 @@ __END__
 
 =head1 NAME
 
-TeX::AutoTeX::PostScript - watermark PostScript files and related manipulations
+TeX::AutoTeX::PostScript
 
 =head1 DESCRIPTION
 
@@ -176,7 +176,7 @@ Contains two methods that make changes to postscript files.
  and that the input of others will benefit arXiv.org.
 
  Code developed and contributed to by Tanmoy Bhattacharya, Rob
- Hartill, Mark Doyle, Thorsten Schwander, and Simeon Warner.
+ Harthill, Mark Doyle, Thorsten Schwander, and Simeon Warner.
  Refactored to separate generic code from arXiv.org specific code
  by Stephen Marsh, Michael Fromerth, and Simeon Warner 2005/2006.
 
