@@ -1,11 +1,11 @@
 package TeX::AutoTeX::Process;
 
 #
-# $Id: Process.pm,v 1.14.2.7 2011/02/03 03:57:38 thorstens Exp $
-# $Revision: 1.14.2.7 $
+# $Id: Process.pm,v 1.14.2.5 2011/01/22 04:52:14 thorstens Exp $
+# $Revision: 1.14.2.5 $
 # $Source: /cvsroot/arxivlib/arXivLib/lib/TeX/AutoTeX/Process.pm,v $
 #
-# $Date: 2011/02/03 03:57:38 $
+# $Date: 2011/01/22 04:52:14 $
 # $Author: thorstens $
 #
 
@@ -13,7 +13,7 @@ use strict;
 ### use warnings;
 use Carp;
 
-our ($VERSION) = '$Revision: 1.14.2.7 $' =~ m{ \$Revision: \s+ (\S+) }x;
+our ($VERSION) = '$Revision: 1.14.2.5 $' =~ m{ \$Revision: \s+ (\S+) }x;
 
 use TeX::AutoTeX::Config qw($AUTOTEX_TIMEOUT $DIRECTIVE_FILE);
 use TeX::AutoTeX::Fileset;
@@ -90,7 +90,7 @@ sub process_files {
   my @unknowns = ();   # names of files with unknown types
   foreach my $fileobj ($self->file_list()) {
     my $filename = $fileobj->{filename};
-    my $filetype = $fileobj->filetype_name();
+    my $filetype = $fileobj->type_name();
     if ( $filetype =~ /(compressed|TAR\sarchive|MULTI_PART_MIME|UUencoded)/i ) {
       $log->error("Package contains '$filename' which is of type '$filetype'. This file should be removed or marked ignore.");
       exit 121;
@@ -369,7 +369,7 @@ __END__
 
 =head1 NAME
 
-TeX::AutoTeX::Process - orchestrate the system calls for tex, dvips, etc.
+TeX::AutoTeX::Process
 
 =head1 DESCRIPTION
 
@@ -393,7 +393,7 @@ inside. Processing of individual files is handled by TeX::AutoTeX::File.
  and that the input of others will benefit arXiv.org.
 
  Code developed and contributed to by Tanmoy Bhattacharya, Rob
- Hartill, Mark Doyle, Thorsten Schwander, and Simeon Warner.
+ Harthill, Mark Doyle, Thorsten Schwander, and Simeon Warner.
  Refactored to separate generic code from arXiv.org specific code
  by Stephen Marsh, Michael Fromerth, and Simeon Warner 2005/2006.
 
